Module quickjs_runtime::builder
source · [−]Expand description
contains the QuickJsRuntimeBuilder which may be used to instantiate a new QuickjsRuntimeFacade
Structs
the EsRuntimeBuilder is used to init an EsRuntime
contains the QuickJsRuntimeBuilder which may be used to instantiate a new QuickjsRuntimeFacade
the EsRuntimeBuilder is used to init an EsRuntime