Module quickjs_runtime::esvalue
source · [−]Expand description
contains the legacy EsValueFacade which will be deprecated in favour of utils::JsValueFacade in the near future
Structs
used to create a new Function
can be used to create a new Promise which is resolved with the resolver function