Module quickjs_runtime::esvalue [−][src]
Structs
used to create a new Function
can be used to create a new Promise which is resolved with the resolver function
used to create a new Function
can be used to create a new Promise which is resolved with the resolver function