Module quickjs_runtime::quickjs_utils
source · [−]Expand description
low level contains utils for calling the quickjs api
Modules
Utils to compile script to bytecode and run script from bytecode
Utils for working with Date objects
utils for getting and reporting exceptions
utils to create and invoke functions
utils for the iterator protocol
serialize and stringify JavaScript objects
utils for working with ES6 Modules
Utils for working with objects
this module is a work in progress and is currently used by me to pass Vec’s from rust to js and back again
Functions
Safety
Safety
Calculate a runtimes memory usage
get the current filename
get the current filename
Safety