utils to create and invoke functions

Functions

call a constructor (instantiate an Object)
call a constructor (instantiate an Object)
call a function
call a function
call a function
call an objects to_String method or convert a value to string
call an objects to_String method or convert a value to string
see if an Object is an instance of Function and is a constructor (can be instantiated with new keyword)
see if an Object is an instance of Function and is a constructor (can be instantiated with new keyword)
see if an Object is an instance of Function
see if an Object is an instance of Function
create a new Function which is backed by a closure
create a new Function which is backed by a closure
create a new Function object which calls a native method
create a new Function object which calls a native method (with data)
create a new Function object which calls a native method (with data)
create a new Function object which calls a native method
parse a function body and its arg_names into a JSValueRef which is a Function