Function quickjs_runtime::quickjs_utils::functions::is_function [−][src]
pub unsafe fn is_function(context: *mut JSContext, obj_ref: &JSValueRef) -> bool
see if an Object is an instance of Function
Safety
When passing a context pointer please make sure the corresponding QuickJsContext is still valid