pub struct QuickJsRealmAdapter {
    pub id: String,
    pub context: *mut JSContext,
    /* private fields */
}

Fields

id: Stringcontext: *mut JSContext

Implementations

get the id of a QuickJsContext from a JSContext

Safety

when passing a context ptr please be sure that the corresponding QuickJsContext is still active

call a function by namespace and name

evaluate a script

Safety

when passing a context ptr please be sure that the corresponding QuickJsContext is still active

evaluate a Module

Safety

when passing a context ptr please be sure that the corresponding QuickJsContext is still active

throw an internal error to quickjs and create a new ex obj

throw an Error in the runtime and init an Exception JSValue to return

Safety

when passing a context ptr please be sure that the corresponding QuickJsContext is still active

Get the last exception from the runtime, and if present, convert it to a JsError.

Get the last exception from the runtime, and if present, convert it to a JsError.

Safety

When passing a context pointer please make sure the corresponding QuickJsContext is still valid

Safety

When passing a context pointer please make sure the corresponding QuickJsContext is still valid