pub struct QuickJsRuntimeAdapter { /* private fields */ }

Implementations

get memory usage for this runtime

Safety

When passing a context pointer please make sure the corresponding QuickJsContext is still valid

run the garbage collector

run pending jobs if avail

todo

move this to a quickjs_utils::pending_jobs so it can be used without doing QuickjsRuntime.do_with()

this method tries to load a module script using the runtimes script_module loaders