utils for implementing proxy classes which can be used to use rust structs from JS (define method/getters/setters/etc)

Modules

EventTarget utils

Structs

The Proxy struct can be used to create a class in JavaScript who’s methods can be implemented in rust

Constants

Functions

get a proxy by class_name (namespace.ClassName)
check if an object is an instance of a Proxy class

Type Definitions