Struct quickjs_runtime::valueref::JSValueRef [−][src]
Implementations
impl JSValueRef[src]
pub fn get_tag(&self) -> i64[src]
pub fn new_no_context(value: JSValue, label: &str) -> Self[src]
pub fn new(
context: *mut JSContext,
value: JSValue,
ref_ct_incr: bool,
ref_ct_decr_on_drop: bool,
label: &str
) -> Self[src]
context: *mut JSContext,
value: JSValue,
ref_ct_incr: bool,
ref_ct_decr_on_drop: bool,
label: &str
) -> Self
pub fn get_ref_count(&self) -> i32[src]
pub fn clone_value_incr_rc(&self) -> JSValue[src]
borrow the value but first increment the refcount, this is useful for when the value is returned or passed to functions
pub fn borrow_value(&self) -> &JSValue[src]
pub fn borrow_value_mut(&mut self) -> &mut JSValue[src]
pub fn is_null_or_undefined(&self) -> bool[src]
pub fn is_undefined(&self) -> bool[src]
return true if the wrapped value represents a JS null value
pub fn is_null(&self) -> bool[src]
return true if the wrapped value represents a JS null value
pub fn is_bool(&self) -> bool[src]
return true if the wrapped value represents a JS boolean value
pub fn is_i32(&self) -> bool[src]
return true if the wrapped value represents a JS INT value
pub fn is_module(&self) -> bool[src]
return true if the wrapped value represents a Module
pub fn is_compiled_function(&self) -> bool[src]
return true if the wrapped value represents a compiled function
pub fn is_f64(&self) -> bool[src]
return true if the wrapped value represents a JS F64 value
pub fn is_big_int(&self) -> bool[src]
pub fn is_exception(&self) -> bool[src]
return true if the wrapped value represents a JS Exception value
pub fn is_object(&self) -> bool[src]
return true if the wrapped value represents a JS Object value
pub fn is_string(&self) -> bool[src]
return true if the wrapped value represents a JS String value